@@ -1,10 +1,12 @@
+from abc import ABC
 from typing import Any, Dict
 
 from ..graph.graph_object import Graph
+from ..model.trained_model import GraphSageModel
 from ..query_runner.query_runner import QueryResult, QueryRunner
 
 
-class AlgoProcRunner:
+class AlgoProcRunner(ABC):
     def __init__(self, query_runner: QueryRunner, proc_name: str):
         self._query_runner = query_runner
         self._proc_name = proc_name
@@ -18,9 +20,18 @@ class AlgoProcRunner:
 
         return self._query_runner.run_query(query, params)
 
-    def __call__(self, G: Graph, **config: Any) -> QueryResult:
-        return self._run_procedure(G, config)
-
     def estimate(self, G: Graph, **config: Any) -> QueryResult:
         self._proc_name += "." + "estimate"
         return self._run_procedure(G, config)
+
+
+class StandardModeRunner(AlgoProcRunner):
+    def __call__(self, G: Graph, **config: Any) -> QueryResult:
+        return self._run_procedure(G, config)
+
+
+class GraphSageRunner(AlgoProcRunner):
+    def __call__(self, G: Graph, **config: Any) -> GraphSageModel:
+        model_name = self._run_procedure(G, config)[0]["modelInfo"]["modelName"]
+
+        return GraphSageModel(model_name, self._query_runner)
