@@ -1,8 +1,9 @@
+from gdsclient.model.trained_model import TrainedModel
+
 from ..query_runner.query_runner import QueryRunner
-from .prediction_pipeline import PredictionPipeline
 
 
-class LPPredictionPipeline(PredictionPipeline):
+class LPPredictionPipeline(TrainedModel):
     def __init__(self, name: str, query_runner: QueryRunner) -> None:
         super().__init__(name, query_runner)
 
